@@ -16,3 +16,9 @@
        INTEGER MPI_DOUBLE_PRECISION
        PARAMETER (MPI_DOUBLE_PRECISION=1)
        INTEGER MPI_BSEND_OVERHEAD
+       INTEGER MPI_MIN
+       PARAMETER(MPI_MIN=1)
+       INTEGER MPI_MAX
+       PARAMETER(MPI_MAX=1)
+       INTEGER MPI_SUM
+       PARAMETER(MPI_SUM=1)
